pub struct UpdatePhaseProcessingMessages;Expand description
Receives Event::Window(UpdatePhase(ProcessingMessages)) — fired at the start of the
update cycle’s message processing phase.
Routing
Dispatched to Target phase only on all views that have registered this listener. Not all phases run every cycle; a single phase may run multiple times per cycle.
Default Actions
No preventable default action.