pub struct WindowCloseRequested;Expand description
Receives Event::Window CloseRequested variant — fired when the system requests
that the window close.
Routing
Dispatched to Target phase only on all views that have registered this listener. Views that do not register a listener do not receive window events.
Default Actions (preventable with cx.prevent_default())
Closes the window unless prevented.